pages = [
    "DelayDiffEq.jl: DDE solvers" => "index.md",
    "Solver API" => "solvers/api.md",
]
